pub fn filter_logs(
block: Block,
receipts: Vec<TypedReceipt>,
filter: &FilteredParams,
) -> Vec<Log>Expand description
Returns all the logs that match the given filter
pub fn filter_logs(
block: Block,
receipts: Vec<TypedReceipt>,
filter: &FilteredParams,
) -> Vec<Log>Returns all the logs that match the given filter